==> primefaces-14.0.0-sources.jar: META-INF/resources/primefaces/locales/locale-sr.js <==
if (window.PrimeFaces) {
  /** Serbian Latin*/
  PrimeFaces.locales["sr"] = {
    accept: "Da",
    addRule: "Dodaj pravilo",
    am: "AM",
    apply: "Primeni",
    cancel: "Otkaži",
    choose: "Izaberi",
    chooseDate: "Izaberi datum",
    chooseMonth: "Izaberi mesec",
    chooseYear: "Izaberi godinu",
    clear: "Očisti",
    completed: "Završeno",
    contains: "Sadrži",
    custom: "Prilagođeno",
    dateAfter: "Datum je posle",
    dateBefore: "Datum je pre",
    dateFormat: "mm/dd/gg",
    dateIs: "Datum je",
    dateIsNot: "Datum nije",
    dayNames: ["Nedelja", "Ponedeljak", "Utorak", "Sreda", "Četvrtak", "Petak", "Subota"],
    dayNamesMin: ["Ne", "Po", "Ut", "Sr", "Če", "Pe", "Su"],
    dayNamesShort: ["Ned", "Pon", "Uto", "Sre", "Čet", "Pet", "Sub"],
    emptyFilterMessage: "Nema pronađenih rezultata",
    emptyMessage: "Nema dostupnih opcija",
    emptySearchMessage: "Nema pronađenih rezultata",
    emptySelectionMessage: "Nije izabrana stavka",
    endsWith: "Završava se sa",
    equals: "Jednako",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    filter: "Filter",
    firstDayOfWeek: 0,
    gt: "Veće od",
    gte: "Veće ili jednako od",
    lt: "Manje od",
    lte: "Manje ili jednako od",
    matchAll: "Poklopi sve",
    matchAny: "Poklopi bilo šta",
    medium: "Srednje",
    monthNames: ["Januar", "Februar", "Mart", "April", "Maj", "Jun", "Jul", "Avgust", "Septembar", "Oktobar", "Novembar", "Decembar"],
    monthNamesShort: ["Jan", "Feb", "Mar", "Apr", "Maj", "Jun", "Jul", "Avg", "Sep", "Okt", "Nov", "Dec"],
    nextDecade: "Sledeća decenija",
    nextHour: "Sledeći sat",
    nextMinute: "Sledeći minut",
    nextMonth: "Sledeći mesec",
    nextSecond: "Sledeća sekunda",
    nextYear: "Sledeća godina",
    noFilter: "Bez filtera",
    notContains: "Ne sadrži",
    notEquals: "Nije jednako",
    now: "Sada",
    passwordPrompt: "Unesite lozinku",
    pending: "Na čekanju",
    pm: "PM",
    prevDecade: "Prethodna decenija",
    prevHour: "Prethodni sat",
    prevMinute: "Prethodni minut",
    prevMonth: "Prethodni mesec",
    prevSecond: "Prethodna sekunda",
    prevYear: "Prethodna godina",
    reject: "Ne",
    removeRule: "Ukloni pravilo",
    searchMessage: "{0} rezultata je dostupno",
    selectionMessage: "Izabrano {0} stavki",
    showMonthAfterYear: false,
    startsWith: "Počinje sa",
    strong: "Snažno",
    today: "Danas",
    upload: "Učitaj",
    weak: "Slabo",
    weekHeader: "Ned",
    aria: {
      cancelEdit: "Otkaži izmenu",
      close: "Zatvori",
      collapseLabel: "Sakrij",
      collapseRow: "Red sakriven",
      editRow: "Izmeni red",
      expandLabel: "Proširi",
      expandRow: "Red proširen",
      falseLabel: "Netačno",
      filterConstraint: "Uslov filtera",
      filterOperator: "Operator filtera",
      firstPageLabel: "Prva stranica",
      gridView: "Pogled mreže",
      hideFilterMenu: "Sakrij meni filtera",
      jumpToPageDropdownLabel: "Skok na stranicu padajućim menijem",
      jumpToPageInputLabel: "Skok na stranicu unosom",
      lastPageLabel: "Poslednja stranica",
      listView: "Pogled liste",
      moveAllToSource: "Pomeri sve u izvor",
      moveAllToTarget: "Pomeri sve u odredište",
      moveBottom: "Pomeri na dno",
      moveDown: "Pomeri dole",
      moveToSource: "Pomeri u izvor",
      moveToTarget: "Pomeri u odredište",
      moveTop: "Pomeri na vrh",
      moveUp: "Pomeri gore",
      navigation: "Navigacija",
      next: "Sledeće",
      nextPageLabel: "Sledeća stranica",
      nullLabel: "Nije izabrano",
      otpLabel: "Unesite karakter jednokratne lozinke {0}",
      pageLabel: "Stranica {page}",
      passwordHide: "Sakrij lozinku",
      passwordShow: "Prikaži lozinku",
      previous: "Prethodno",
      previousPageLabel: "Prethodna stranica",
      rotateLeft: "Rotiraj levo",
      rotateRight: "Rotiraj desno",
      rowsPerPageLabel: "Redova po stranici",
      saveEdit: "Sačuvaj izmenu",
      scrollTop: "Vrati se na vrh",
      selectAll: "Sve stavke izabrane",
      selectLabel: "Izaberi",
      selectRow: "Red izabran",
      showFilterMenu: "Prikaži meni filtera",
      slide: "Klizanje",
      slideNumber: "{slideNumber}",
      star: "1 zvezda",
      stars: "{star} zvezde",
      trueLabel: "Tačno",
      unselectAll: "Sve stavke odabrane",
      unselectLabel: "Poništi izbor",
      unselectRow: "Red odabran",
      zoomImage: "Uvećaj sliku",
      zoomIn: "Povećaj",
      zoomOut: "Smanji",
    },
  };

  // custom PF labels
  PrimeFaces.locales["sr"] = $.extend(true, {}, PrimeFaces.locales["sr"], {
    weekNumberTitle: "Ned",
    isRTL: false,
    yearSuffix: "",
    timeOnlyTitle: "Samo vreme",
    timeText: "Vreme",
    hourText: "Sat",
    minuteText: "Minut",
    secondText: "Sekunda",
    millisecondText: "Milisekunda",
    year: "Godina",
    month: "Mesec",
    week: "Nedelja",
    day: "Dan",
    list: "Agenda",
    allDayText: "Ceo dan",
    moreLinkText: "Više...",
    noEventsText: "Nema događaja",
    unexpectedError: "Neočekivana greška",
    aria: {
      "datatable.sort.ASC": "Aktivirajte sortiranje kolone uzlazno",
      "datatable.sort.DESC": "Aktivirajte sortiranje kolone silazno",
      "datatable.sort.NONE": "Aktivirajte uklanjanje sortiranja na koloni",
      "colorpicker.OPEN": "Otvori paletu boja",
      "colorpicker.CLOSE": "Zatvori paletu boja",
      "colorpicker.CLEAR": "Obriši izabranu boju",
      "colorpicker.MARKER": "Zasićenost: {s}. Osvetljenje: {v}.",
      "colorpicker.HUESLIDER": "Klizač nijanse",
      "colorpicker.ALPHASLIDER": "Klizač providnosti",
      "colorpicker.INPUT": "Polje za unos vrednosti boje",
      "colorpicker.FORMAT": "Format boje",
      "colorpicker.SWATCH": "Uzorak boje",
      "colorpicker.INSTRUCTION": "Selektor zasićenosti i osvetljenja. Koristite strelice gore, dole, levo i desno za izbor.",
      "spinner.INCREASE": "Povećaj vrednost",
      "spinner.DECREASE": "Smanji vrednost",
      "switch.ON": "Uključeno",
      "switch.OFF": "Isključeno",
      "messages.ERROR": "Greška",
      "messages.FATAL": "Fatalno",
      "messages.INFO": "Informacija",
      "messages.WARN": "Upozorenje",
    },
    messages: {
      //optional for Client Side Validation
      "javax.faces.component.UIInput.REQUIRED": "{0}: Greška validacije: Vrednost je obavezna.",
      // other messages...
    },
  });

  /** Serbian Cyrillic (from PrimeLocale)*/
  PrimeFaces.locales["sr_RS"] = $.extend(true, {}, PrimeFaces.locales["sr"], {
    accept: "Прихвати",
    addRule: "Додај правило",
    am: "AM",
    apply: "Примени",
    cancel: "Откажи",
    choose: "Изабери",
    chooseDate: "Изабери датум",
    chooseMonth: "Изабери месец",
    chooseYear: "Изабери годину",
    clear: "Очисти",
    completed: "Завршено",
    contains: "Садржи",
    custom: "Прилагођено",
    dateAfter: "Датум је после",
    dateBefore: "Датум је пре",
    dateFormat: "dd.mm.yy.",
    dateIs: "Датум је",
    dateIsNot: "Датум није",
    dayNames: ["Недеља", "Понедељак", "Уторак", "Среда", "Четвртак", "Петак", "Субота"],
    dayNamesMin: ["Не", "По", "Ут", "Ср", "Че", "Пе", "Су"],
    dayNamesShort: ["Нед", "Пон", "Уто", "Сре", "Чет", "Пет", "Суб"],
    emptyFilterMessage: "Нема пронађених резултата",
    emptyMessage: "Нема доступних опција",
    emptySearchMessage: "Нема пронађених резултата",
    emptySelectionMessage: "Нема одабраних ставки",
    endsWith: "Завршава са",
    equals: "Једнако",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    filter: "Филтер",
    firstDayOfWeek: 1,
    gt: "Веће од",
    gte: "Веће или једнако",
    lt: "Мање од",
    lte: "Мање или једнако",
    matchAll: "Подударају се сви",
    matchAny: "Подударају се било који",
    medium: "Средње",
    monthNames: ["Јануар", "Фебруар", "Март", "Април", "Мај", "Јун", "Јул", "Август", "Септембар", "Октобар", "Новембар", "Децембар"],
    monthNamesShort: ["Јан", "Феб", "Мар", "Апр", "Мај", "Јун", "Јул", "Авг", "Сеп", "Окт", "Нов", "Дец"],
    nextDecade: "Наредна деценија",
    nextHour: "Наредни сат",
    nextMinute: "Наредни минут",
    nextMonth: "Наредни месец",
    nextSecond: "Наредна секунда",
    nextYear: "Наредна година",
    noFilter: "Без филтeра",
    notContains: "Не садржи",
    notEquals: "Није једнако",
    now: "Сада",
    passwordPrompt: "Унесите лозинку",
    pending: "На чекању",
    pm: "PM",
    prevDecade: "Претходна деценија",
    prevHour: "Претходни сат",
    prevMinute: "Претходни минут",
    prevMonth: "Претходни месец",
    prevSecond: "Претходна секунда",
    prevYear: "Претходна година",
    reject: "Одбаци",
    removeRule: "Уклони правило",
    searchMessage: "Доступно резултата: {0}",
    selectionMessage: "Одабрано ставки: {0}",
    showMonthAfterYear: false,
    startsWith: "Почиње са",
    strong: "Јако",
    today: "Данас",
    upload: "Постави",
    weak: "Слабо",
    weekHeader: "Сед",
    weekNumberTitle: "Н",
    isRTL: false,
    yearSuffix: "",
    timeOnlyTitle: "Само време",
    timeText: "Време",
    hourText: "Сат",
    minuteText: "Минут",
    secondText: "Секунда",
    millisecondText: "Милисекунда",
    year: "Година",
    month: "Месец",
    week: "Недеља",
    day: "Дан",
    list: "Агенда",
    allDayText: "Целог дана",
    moreLinkText: "Више...",
    noEventsText: "Нема догађаја",
    unexpectedError: "Неочекивана грешка",
    aria: {
      cancelEdit: "Откажи измене",
      close: "Затвори",
      collapseLabel: "Склопи",
      collapseRow: "Склопи ред",
      editRow: "Измени ред",
      expandLabel: "Прошири",
      expandRow: "Прошири ред",
      falseLabel: "Није тачно",
      filterConstraint: "Ограничење филтера",
      filterOperator: "Оператор филтера",
      firstPageLabel: "Прва страна",
      gridView: "Приказ у табели",
      hideFilterMenu: "Сакри мени филтера",
      jumpToPageDropdownLabel: "Скок на страну (падајући мени)",
      jumpToPageInputLabel: "Скок на страну (унос)",
      lastPageLabel: "Последња страна",
      listView: "Приказ у листи",
      moveAllToSource: "Помакни све на извор",
      moveAllToTarget: "Помакни све на циљ",
      moveBottom: "Помакни на дно",
      moveDown: "Помакни доле",
      moveTop: "Помакни на врх",
      moveToSource: "Помакни на извор",
      moveToTarget: "Помакни на циљ",
      moveUp: "Помакни горе",
      navigation: "Навигација",
      next: "Следеће",
      nextPageLabel: "Следећа страна",
      nullLabel: "Није одабрано",
      otpLabel: "Унесите једнократну лозинку {0}",
      pageLabel: "Страна {page}",
      passwordHide: "Сакри лозинку",
      passwordShow: "Прикажи лозинку",
      previous: "Претходно",
      previousPageLabel: "Претходна страна",
      rotateLeft: "Ротирај лево",
      rotateRight: "Ротирај десно",
      rowsPerPageLabel: "Редова по страни",
      saveEdit: "Сачувај измене",
      scrollTop: "Скрол на врх",
      selectAll: "Одабране су све ставке",
      selectLabel: "Одабери",
      selectRow: "Ред одабран",
      showFilterMenu: "Прикажи филтер мени",
      slide: "Слајд",
      slideNumber: "Слајд {slideNumber}",
      star: "1 Звезда",
      stars: "Звезда: {start}",
      trueLabel: "Тачно",
      unselectAll: "Поништен је одабир свих ставки",
      unselectLabel: "Поништи одабир",
      unselectRow: "Ред није одабран",
      zoomImage: "Зумирај слику",
      zoomIn: "Увећај",
      zoomOut: "Смањи",
      "datatable.sort.ASC": "активирајте за сортирање колоне растуће",
      "datatable.sort.DESC": "активирајте за сортирање колоне опадајуће",
      "datatable.sort.NONE": "активирајте за уклањање сортирања на колони",
      "colorpicker.OPEN": "Отвори палету боја",
      "colorpicker.CLOSE": "Затвори палету боја",
      "colorpicker.CLEAR": "Обриши изабрану боју",
      "colorpicker.MARKER": "Засићење: {s}. Осветљење: {v}.",
      "colorpicker.HUESLIDER": "Померач нијансе",
      "colorpicker.ALPHASLIDER": "Померач прозирности",
      "colorpicker.INPUT": "Поље за унос вредности боје",
      "colorpicker.FORMAT": "Формат боје",
      "colorpicker.SWATCH": "Узорак боје",
      "colorpicker.INSTRUCTION": "Селектор засићења и осветљења. Користите стрелице горе, доле, лево и десно за избор.",
      "spinner.INCREASE": "Повећај вредност",
      "spinner.DECREASE": "Смањи вредност",
      "switch.ON": "Укључено",
      "switch.OFF": "Искључено",
      "messages.ERROR": "Грешка",
      "messages.FATAL": "Фатално",
      "messages.INFO": "Информација",
      "messages.WARN": "Упозорење",
    },
  });
}

==> primefaces-15.0.4-sources.jar: META-INF/resources/primefaces/locales/locale-sr.js <==
if (window.PrimeFaces) {
  /** Serbian Latin*/
  PrimeFaces.locales["sr"] = {
    accept: "Da",
    addRule: "Dodaj pravilo",
    am: "AM",
    apply: "Primeni",
    cancel: "Otkaži",
    choose: "Izaberi",
    chooseDate: "Izaberi datum",
    chooseMonth: "Izaberi mesec",
    chooseYear: "Izaberi godinu",
    clear: "Očisti",
    completed: "Završeno",
    contains: "Sadrži",
    custom: "Prilagođeno",
    dateAfter: "Datum je posle",
    dateBefore: "Datum je pre",
    dateFormat: "mm/dd/gg",
    dateIs: "Datum je",
    dateIsNot: "Datum nije",
    dayNames: ["Nedelja", "Ponedeljak", "Utorak", "Sreda", "Četvrtak", "Petak", "Subota"],
    dayNamesMin: ["Ne", "Po", "Ut", "Sr", "Če", "Pe", "Su"],
    dayNamesShort: ["Ned", "Pon", "Uto", "Sre", "Čet", "Pet", "Sub"],
    emptyFilterMessage: "Nema pronađenih rezultata",
    emptyMessage: "Nema dostupnih opcija",
    emptySearchMessage: "Nema pronađenih rezultata",
    emptySelectionMessage: "Nije izabrana stavka",
    endsWith: "Završava se sa",
    equals: "Jednako",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    filter: "Filter",
    firstDayOfWeek: 0,
    gt: "Veće od",
    gte: "Veće ili jednako od",
    lt: "Manje od",
    lte: "Manje ili jednako od",
    matchAll: "Poklopi sve",
    matchAny: "Poklopi bilo šta",
    medium: "Srednje",
    monthNames: ["Januar", "Februar", "Mart", "April", "Maj", "Jun", "Jul", "Avgust", "Septembar", "Oktobar", "Novembar", "Decembar"],
    monthNamesShort: ["Jan", "Feb", "Mar", "Apr", "Maj", "Jun", "Jul", "Avg", "Sep", "Okt", "Nov", "Dec"],
    nextDecade: "Sledeća decenija",
    nextHour: "Sledeći sat",
    nextMinute: "Sledeći minut",
    nextMonth: "Sledeći mesec",
    nextSecond: "Sledeća sekunda",
    nextYear: "Sledeća godina",
    noFilter: "Bez filtera",
    notContains: "Ne sadrži",
    notEquals: "Nije jednako",
    now: "Sada",
    passwordPrompt: "Unesite lozinku",
    pending: "Na čekanju",
    pm: "PM",
    prevDecade: "Prethodna decenija",
    prevHour: "Prethodni sat",
    prevMinute: "Prethodni minut",
    prevMonth: "Prethodni mesec",
    prevSecond: "Prethodna sekunda",
    prevYear: "Prethodna godina",
    reject: "Ne",
    removeRule: "Ukloni pravilo",
    searchMessage: "{0} rezultata je dostupno",
    selectionMessage: "Izabrano {0} stavki",
    showMonthAfterYear: false,
    startsWith: "Počinje sa",
    strong: "Snažno",
    today: "Danas",
    upload: "Učitaj",
    weak: "Slabo",
    weekHeader: "Ned",
    aria: {
      cancelEdit: "Otkaži izmenu",
      close: "Zatvori",
      collapseLabel: "Sakrij",
      collapseRow: "Red sakriven",
      editRow: "Izmeni red",
      expandLabel: "Proširi",
      expandRow: "Red proširen",
      falseLabel: "Netačno",
      filterConstraint: "Uslov filtera",
      filterOperator: "Operator filtera",
      firstPageLabel: "Prva stranica",
      gridView: "Pogled mreže",
      hideFilterMenu: "Sakrij meni filtera",
      jumpToPageDropdownLabel: "Skok na stranicu padajućim menijem",
      jumpToPageInputLabel: "Skok na stranicu unosom",
      lastPageLabel: "Poslednja stranica",
      listView: "Pogled liste",
      moveAllToSource: "Pomeri sve u izvor",
      moveAllToTarget: "Pomeri sve u odredište",
      moveBottom: "Pomeri na dno",
      moveDown: "Pomeri dole",
      moveToSource: "Pomeri u izvor",
      moveToTarget: "Pomeri u odredište",
      moveTop: "Pomeri na vrh",
      moveUp: "Pomeri gore",
      navigation: "Navigacija",
      next: "Sledeće",
      nextPageLabel: "Sledeća stranica",
      nullLabel: "Nije izabrano",
      otpLabel: "Unesite karakter jednokratne lozinke {0}",
      pageLabel: "Stranica {page}",
      passwordHide: "Sakrij lozinku",
      passwordShow: "Prikaži lozinku",
      previous: "Prethodno",
      prevPageLabel: "Prethodna stranica",
      rotateLeft: "Rotiraj levo",
      rotateRight: "Rotiraj desno",
      rowsPerPageLabel: "Redova po stranici",
      saveEdit: "Sačuvaj izmenu",
      scrollTop: "Vrati se na vrh",
      selectAll: "Sve stavke izabrane",
      selectLabel: "Izaberi",
      selectRow: "Red izabran",
      showFilterMenu: "Prikaži meni filtera",
      slide: "Klizanje",
      slideNumber: "{slideNumber}",
      star: "1 zvezda",
      stars: "{star} zvezde",
      trueLabel: "Tačno",
      unselectAll: "Sve stavke odabrane",
      unselectLabel: "Poništi izbor",
      unselectRow: "Red odabran",
      zoomImage: "Uvećaj sliku",
      zoomIn: "Povećaj",
      zoomOut: "Smanji",
    },
  };

  // custom PF labels
  PrimeFaces.locales["sr"] = $.extend(true, {}, PrimeFaces.locales["sr"], {
    weekNumberTitle: "Ned",
    isRTL: false,
    yearSuffix: "",
    timeOnlyTitle: "Samo vreme",
    timeText: "Vreme",
    hourText: "Sat",
    minuteText: "Minut",
    secondText: "Sekunda",
    millisecondText: "Milisekunda",
    year: "Godina",
    month: "Mesec",
    week: "Nedelja",
    day: "Dan",
    list: "Agenda",
    allDayText: "Ceo dan",
    moreLinkText: "Više...",
    noEventsText: "Nema događaja",
    unexpectedError: "Neočekivana greška",
    aria: {
      "datatable.sort.ASC": "Aktivirajte sortiranje kolone uzlazno",
      "datatable.sort.DESC": "Aktivirajte sortiranje kolone silazno",
      "datatable.sort.NONE": "Aktivirajte uklanjanje sortiranja na koloni",
      "colorpicker.OPEN": "Otvori paletu boja",
      "colorpicker.CLOSE": "Zatvori paletu boja",
      "colorpicker.CLEAR": "Obriši izabranu boju",
      "colorpicker.MARKER": "Zasićenost: {s}. Osvetljenje: {v}.",
      "colorpicker.HUESLIDER": "Klizač nijanse",
      "colorpicker.ALPHASLIDER": "Klizač providnosti",
      "colorpicker.INPUT": "Polje za unos vrednosti boje",
      "colorpicker.FORMAT": "Format boje",
      "colorpicker.SWATCH": "Uzorak boje",
      "colorpicker.INSTRUCTION": "Selektor zasićenosti i osvetljenja. Koristite strelice gore, dole, levo i desno za izbor.",
      "spinner.INCREASE": "Povećaj vrednost",
      "spinner.DECREASE": "Smanji vrednost",
      "switch.ON": "Uključeno",
      "switch.OFF": "Isključeno",
      "messages.ERROR": "Greška",
      "messages.FATAL": "Fatalno",
      "messages.INFO": "Informacija",
      "messages.WARN": "Upozorenje",
    },
    messages: {
      //optional for Client Side Validation
      "javax.faces.component.UIInput.REQUIRED": "{0}: Greška validacije: Vrednost je obavezna.",
      // other messages...
    },
  });

  /** Serbian Cyrillic (from PrimeLocale)*/
  PrimeFaces.locales["sr_RS"] = $.extend(true, {}, PrimeFaces.locales["sr"], {
    accept: "Прихвати",
    addRule: "Додај правило",
    am: "AM",
    apply: "Примени",
    cancel: "Откажи",
    choose: "Изабери",
    chooseDate: "Изабери датум",
    chooseMonth: "Изабери месец",
    chooseYear: "Изабери годину",
    clear: "Очисти",
    completed: "Завршено",
    contains: "Садржи",
    custom: "Прилагођено",
    dateAfter: "Датум је после",
    dateBefore: "Датум је пре",
    dateFormat: "dd.mm.yy.",
    dateIs: "Датум је",
    dateIsNot: "Датум није",
    dayNames: ["Недеља", "Понедељак", "Уторак", "Среда", "Четвртак", "Петак", "Субота"],
    dayNamesMin: ["Не", "По", "Ут", "Ср", "Че", "Пе", "Су"],
    dayNamesShort: ["Нед", "Пон", "Уто", "Сре", "Чет", "Пет", "Суб"],
    emptyFilterMessage: "Нема пронађених резултата",
    emptyMessage: "Нема доступних опција",
    emptySearchMessage: "Нема пронађених резултата",
    emptySelectionMessage: "Нема одабраних ставки",
    endsWith: "Завршава са",
    equals: "Једнако",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    filter: "Филтер",
    firstDayOfWeek: 1,
    gt: "Веће од",
    gte: "Веће или једнако",
    lt: "Мање од",
    lte: "Мање или једнако",
    matchAll: "Подударају се сви",
    matchAny: "Подударају се било који",
    medium: "Средње",
    monthNames: ["Јануар", "Фебруар", "Март", "Април", "Мај", "Јун", "Јул", "Август", "Септембар", "Октобар", "Новембар", "Децембар"],
    monthNamesShort: ["Јан", "Феб", "Мар", "Апр", "Мај", "Јун", "Јул", "Авг", "Сеп", "Окт", "Нов", "Дец"],
    nextDecade: "Наредна деценија",
    nextHour: "Наредни сат",
    nextMinute: "Наредни минут",
    nextMonth: "Наредни месец",
    nextSecond: "Наредна секунда",
    nextYear: "Наредна година",
    noFilter: "Без филтeра",
    notContains: "Не садржи",
    notEquals: "Није једнако",
    now: "Сада",
    passwordPrompt: "Унесите лозинку",
    pending: "На чекању",
    pm: "PM",
    prevDecade: "Претходна деценија",
    prevHour: "Претходни сат",
    prevMinute: "Претходни минут",
    prevMonth: "Претходни месец",
    prevSecond: "Претходна секунда",
    prevYear: "Претходна година",
    reject: "Одбаци",
    removeRule: "Уклони правило",
    searchMessage: "Доступно резултата: {0}",
    selectionMessage: "Одабрано ставки: {0}",
    showMonthAfterYear: false,
    startsWith: "Почиње са",
    strong: "Јако",
    today: "Данас",
    upload: "Постави",
    weak: "Слабо",
    weekHeader: "Сед",
    weekNumberTitle: "Н",
    isRTL: false,
    yearSuffix: "",
    timeOnlyTitle: "Само време",
    timeText: "Време",
    hourText: "Сат",
    minuteText: "Минут",
    secondText: "Секунда",
    millisecondText: "Милисекунда",
    year: "Година",
    month: "Месец",
    week: "Недеља",
    day: "Дан",
    list: "Агенда",
    allDayText: "Целог дана",
    moreLinkText: "Више...",
    noEventsText: "Нема догађаја",
    unexpectedError: "Неочекивана грешка",
    aria: {
      cancelEdit: "Откажи измене",
      close: "Затвори",
      collapseLabel: "Склопи",
      collapseRow: "Склопи ред",
      editRow: "Измени ред",
      expandLabel: "Прошири",
      expandRow: "Прошири ред",
      falseLabel: "Није тачно",
      filterConstraint: "Ограничење филтера",
      filterOperator: "Оператор филтера",
      firstPageLabel: "Прва страна",
      gridView: "Приказ у табели",
      hideFilterMenu: "Сакри мени филтера",
      jumpToPageDropdownLabel: "Скок на страну (падајући мени)",
      jumpToPageInputLabel: "Скок на страну (унос)",
      lastPageLabel: "Последња страна",
      listView: "Приказ у листи",
      moveAllToSource: "Помакни све на извор",
      moveAllToTarget: "Помакни све на циљ",
      moveBottom: "Помакни на дно",
      moveDown: "Помакни доле",
      moveTop: "Помакни на врх",
      moveToSource: "Помакни на извор",
      moveToTarget: "Помакни на циљ",
      moveUp: "Помакни горе",
      navigation: "Навигација",
      next: "Следеће",
      nextPageLabel: "Следећа страна",
      nullLabel: "Није одабрано",
      otpLabel: "Унесите једнократну лозинку {0}",
      pageLabel: "Страна {page}",
      passwordHide: "Сакри лозинку",
      passwordShow: "Прикажи лозинку",
      previous: "Претходно",
      prevPageLabel: "Претходна страна",
      rotateLeft: "Ротирај лево",
      rotateRight: "Ротирај десно",
      rowsPerPageLabel: "Редова по страни",
      saveEdit: "Сачувај измене",
      scrollTop: "Скрол на врх",
      selectAll: "Одабране су све ставке",
      selectLabel: "Одабери",
      selectRow: "Ред одабран",
      showFilterMenu: "Прикажи филтер мени",
      slide: "Слајд",
      slideNumber: "Слајд {slideNumber}",
      star: "1 Звезда",
      stars: "Звезда: {start}",
      trueLabel: "Тачно",
      unselectAll: "Поништен је одабир свих ставки",
      unselectLabel: "Поништи одабир",
      unselectRow: "Ред није одабран",
      zoomImage: "Зумирај слику",
      zoomIn: "Увећај",
      zoomOut: "Смањи",
      "datatable.sort.ASC": "активирајте за сортирање колоне растуће",
      "datatable.sort.DESC": "активирајте за сортирање колоне опадајуће",
      "datatable.sort.NONE": "активирајте за уклањање сортирања на колони",
      "colorpicker.OPEN": "Отвори палету боја",
      "colorpicker.CLOSE": "Затвори палету боја",
      "colorpicker.CLEAR": "Обриши изабрану боју",
      "colorpicker.MARKER": "Засићење: {s}. Осветљење: {v}.",
      "colorpicker.HUESLIDER": "Померач нијансе",
      "colorpicker.ALPHASLIDER": "Померач прозирности",
      "colorpicker.INPUT": "Поље за унос вредности боје",
      "colorpicker.FORMAT": "Формат боје",
      "colorpicker.SWATCH": "Узорак боје",
      "colorpicker.INSTRUCTION": "Селектор засићења и осветљења. Користите стрелице горе, доле, лево и десно за избор.",
      "spinner.INCREASE": "Повећај вредност",
      "spinner.DECREASE": "Смањи вредност",
      "switch.ON": "Укључено",
      "switch.OFF": "Искључено",
      "messages.ERROR": "Грешка",
      "messages.FATAL": "Фатално",
      "messages.INFO": "Информација",
      "messages.WARN": "Упозорење",
    },
  });
}
